#
# spec file for package perl-CGI-Session
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name CGI-Session
Name:           perl-CGI-Session
Version:        4.480.0
Release:        1.2
# 4.48 -> normalize -> 4.480.0
%define cpan_version 4.48
#Upstream: Artistic-1.0
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Persistent session data in CGI applications
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MARKSTOS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CGI) >= 3.260
BuildRequires:  perl(Module::Build) >= 0.38
Requires:       perl(CGI) >= 3.260
Provides:       perl(CGI::Session) = %{version}
Provides:       perl(CGI::Session::Driver) = 4.430.0
Provides:       perl(CGI::Session::Driver::DBI) = 4.430.0
Provides:       perl(CGI::Session::Driver::db_file) = 4.430.0
Provides:       perl(CGI::Session::Driver::file) = 4.430.0
Provides:       perl(CGI::Session::Driver::mysql) = 4.430.0
Provides:       perl(CGI::Session::Driver::postgresql) = 4.430.0
Provides:       perl(CGI::Session::Driver::sqlite) = 4.430.0
Provides:       perl(CGI::Session::ErrorHandler) = 4.430.0
Provides:       perl(CGI::Session::ID::incr) = 4.430.0
Provides:       perl(CGI::Session::ID::md5) = 4.430.0
Provides:       perl(CGI::Session::ID::static) = 4.440.0
Provides:       perl(CGI::Session::Serialize::default) = 4.430.0
Provides:       perl(CGI::Session::Serialize::freezethaw) = 4.430.0
Provides:       perl(CGI::Session::Serialize::storable) = 4.430.0
Provides:       perl(CGI::Session::Test::Default) = 4.470.0
Provides:       perl(CGI::Session::Test::SimpleObjectClass)
Provides:       perl(CGI::Session::Tutorial) = 4.430.0
Provides:       perl(OverloadedClass)
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
# DB tests need a running database and the following
# variables set to proceed: DBI_DSN/DBI_USER/DBI_PASS
# Disabled by not installing the perl modules for now, as
# this needs to be done for all backends during build which
# increases the dependencies of the package
# running SQLite tests should be enough for now
BuildRequires:  perl-DBD-SQLite
BuildRequires:  perl(CGI::Simple)
BuildRequires:  perl(FreezeThaw)
# MANUAL END

%description
CGI::Session provides an easy, reliable and modular session management
system across HTTP requests.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README

%changelog
* Thu Jun 12 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Thu Aug 27 2015 hsk@imb-jena.de
- add "BuildRequires: CGI" to .spec file so "make test" succeeds
  with perl-5.22
* Mon Jul 25 2011 vcizek@novell.com
- update to 4.48
    Test changes
  * INTERNAL: quit using "use diagnostics;" to avert some test failures
* Tue Jul 12 2011 vcizek@novell.com
- licence correction (same as Perl)
* Mon Jul 11 2011 vcizek@novell.com
- update to 4.47
  * DOCS: minor POD fixes (Rene Mayorga and Nicholas Bamber)
  * INTERNAL: More packaging fixes.
  * INTERNAL: Fix packaging problem with 4.44.
  * FIX: Fix 5.14 compatibility issue (Walt Arstingstall)
  * DOCS: Clarify docs for static ID generator (oalders)
* Thu Jan 20 2011 vcizek@novell.com
- update to 4.43
  * FIX: Avoid deleting unmatched sessions when calling find() when ip_match is enabled.
    Closes RT#47795. Thanks to m-uchino, Ron Savage, and Mark Stosberg
  * NEW: new public ip_match() method is available, primarily for use with find(). (Ron Savage, Mark Stosberg)
  * DOCS: UTF8 related documentation was updated.
  * INTERNAL: Don't add _SESSION_EXPIRE_LIST to internal hash unless we need to.
    RT#51192, Thanks to Pavel V. Rochnyack, Ron Savage, Mark Stosberg
  * INTERNAL: Avoid calling sprintf() in CGI::Session::ErrorHandler, fixing RT#48733
    Solves taint error for Perl V 5.10.0. All well-written code will have
    been using errstr() to retrieve errors anyway so this change will not
    affect any code which obeys the API. (Peter Kaminsk, Ron Savage, Mark Stosberg)
  * INTERNAL: The undocumented 4th parameter to load() has changed its meaning.
  * INTERNAL: Test suite improvements. (Ron Savage, Mark Stosberg)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Aug 27 2009 lars@linux-schulserver.de
- update to 4.42:
  * Fix broken links in documentation and tests. (RT##49020)
- add perl-DBD-SQLite, perl(CGI::Simple) and perl(FreezeThaw) to
  BuildRequires to run more tests (DBI tests needing a running
  database and are skipped so far)
- follow perl packaging rules in specfile
* Mon Mar 23 2009 anicka@suse.cz
- update to 4.41
  * FIX: RT#43290. In CGI::Session::Driver::sqlite, ensure database
  handle is still defined in DESTROY() before calling ping().
  * DOCUMENTATION: Add comments about using the header() method
  to set the charset to 'utf-8'.
* Tue Jan 20 2009 anicka@suse.cz
- update to 4.40
  * many fixes, improved documentation
* Fri Jul 18 2008 anicka@suse.cz
- update to 4.35 (bnc#410259)
  * FIX: Fix the bug fix for error propagation from 4.34
  * FIX: Reset errors when creating a new object. Previously,
    errors from a previous object could show up in the current object.
  * INTERNAL - Patch Build.PL and Makefile.PL to run
    Module::Metadata::Changes's ini.report.pl, if available, to
    regenerate Changelog.ini from this file (Changes), when creating
    a makefile.
  * SECURITY: Patch CGI::Session::Driver::file to stop \ and /
    characters being used in session ids and hence in file names.
    These characters, possibly combined with '..', could have been
    used to access files outside the designated session file directory.
  * FIX: Patch CGI::Session to propagate error upwards when
    _load_pluggables() fails.
  * INTERNAL: Ship a machine-readable version of this file under
    the name Changelog.ini.
  * FIX: Patch CGI::Session::Driver::mysql to replace
    'REPLACE INTO ...' with 'INSERT INTO ... ON DUPLICATE KEY UPDATE ...'.
  * FIX: t/mysql.t used to test setting the global variable
    $CGI::Session::MySQL::TABLE_NAME.
* Wed Jun 25 2008 anicka@suse.cz
- package created (version 4.32)
